@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2013 Aurimas Cernius
+ * Copyright (C) 2011-2014 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -198,6 +198,8 @@ namespace gnote {
         m_note.queue_save(NO_CHANGE);
       }
     }
+
+    m_note.save();  // to update not title immediately in notes list
   }
 
   void NoteWindow::hint_size(int & width, int & height)
@@ -395,28 +397,28 @@ namespace gnote {
   //
   Gtk::Grid *NoteWindow::make_toolbar()
   {
-    Gtk::IconSize icon_size = Gtk::IconSize::from_name(gtk_icon_size_get_name(GTK_ICON_SIZE_SMALL_TOOLBAR));
-
     Gtk::Grid *grid = manage(new Gtk::Grid);
     int grid_col = 0;
 
     m_pin_image = manage(new Gtk::Image);
+    m_pin_button = manage(new Gtk::ToolButton(*m_pin_image, _("Pin")));
+
     if(m_note.is_pinned()) {
       m_pin_image->property_gicon() = get_icon_pin_down();
+      m_pin_button->set_tooltip_text(_("Remove from important notes"));
     }
     else {
       m_pin_image->property_gicon() = get_icon_pin_active();
+      m_pin_button->set_tooltip_text(_("Mark note as important"));
     }
 
-    m_pin_button = manage(new Gtk::ToolButton(*m_pin_image, _("Pin")));
-    m_pin_button->set_tooltip_text(_("Mark note as important"));
     m_pin_button->signal_clicked().connect(sigc::mem_fun(*this, &NoteWindow::on_pin_button_clicked));
     grid->attach(*m_pin_button, grid_col++, 0, 1, 1);
     notebooks::NotebookManager::obj().signal_note_pin_status_changed
       .connect(sigc::mem_fun(*this, &NoteWindow::on_pin_status_changed));
 
     m_link_button = manage(new Gtk::ToolButton(
-                             *manage(new Gtk::Image(Gtk::Stock::JUMP_TO, icon_size)),
+                             *manage(new Gtk::Image(Gtk::Stock::JUMP_TO, Gtk::ICON_SIZE_SMALL_TOOLBAR)),
                              _("Link")));
     m_link_button->set_use_underline(true);
     m_link_button->set_is_important(true);
@@ -428,7 +430,8 @@ namespace gnote {
     grid->attach(*m_link_button, grid_col++, 0, 1, 1);
 
     utils::ToolMenuButton *text_button = manage(new utils::ToolMenuButton(
-        *manage(new Gtk::Image(Gtk::Stock::SELECT_FONT, icon_size)), _("_Text"), m_text_menu));
+        *manage(new Gtk::Image(Gtk::Stock::SELECT_FONT, Gtk::ICON_SIZE_SMALL_TOOLBAR)),
+        _("_Text"), m_text_menu));
     text_button->set_use_underline(true);
     text_button->set_is_important(true);
     text_button->show_all();
@@ -615,9 +618,11 @@ namespace gnote {
     }
     if(pinned) {
       m_pin_image->property_gicon() = get_icon_pin_down();
+      m_pin_button->set_tooltip_text(_("Remove from important notes"));
     }
     else {
       m_pin_image->property_gicon() = get_icon_pin_active();
+      m_pin_button->set_tooltip_text(_("Mark note as important"));
     }
   }
 
